# Examples


```{eval-rst}
.. literalinclude:: ../src/nvbenjo/conf/example.yaml
   :language: yaml
   :caption: Example Configuration
```

## Onnx

```{eval-rst}
.. literalinclude:: ../src/nvbenjo/conf/onnx.yaml
   :language: yaml
   :caption: Example Configuration of Onnx Model
```

```{eval-rst}
.. literalinclude:: ../src/nvbenjo/conf/onnxsilero.yaml
   :language: yaml
   :caption: Example Configuration of Onnx-Silero Model
```


## PyTorch

### Torchvision

```{eval-rst}
.. literalinclude:: ../src/nvbenjo/conf/torchvision.yaml
   :language: yaml
   :caption: Example Configuration of Torchvision Models
```

### Huggingface

```{eval-rst}
.. literalinclude:: ../src/nvbenjo/conf/huggingface.yaml
   :language: yaml
   :caption: Example Configuration of Huggingface Models
```